@@ -3,7 +3,8 @@ from simple_ddl_parser.utils import check_spec, remove_par
 
 class HQL:
     def p_expression_location(self, p):
-        """expr : expr LOCATION STRING"""
+        """expr : expr LOCATION STRING
+        | expr LOCATION DQ_STRING"""
         p[0] = p[1]
         p_list = list(p)
         p[0]["location"] = p_list[-1]
@@ -42,11 +43,12 @@ class HQL:
         p[0]["row_format"] = format
 
     def p_expression_with_serde(self, p):
-        """expr : expr WITH SERDEPROPERTIES LP assigment RP"""
+        """expr : expr WITH SERDEPROPERTIES multi_assigments"""
         p[0] = p[1]
         p_list = list(p)
+
         row_format = p[0]["row_format"]
-        row_format["properties"] = p_list[-2]
+        row_format["properties"] = p_list[-1]
         p[0]["row_format"] = row_format
 
     def p_expression_tblproperties(self, p):
