@@ -7,12 +7,6 @@ class Snowflake:
         p_list = list(p)
         p[0] = {"clone": {"from": p_list[-1]}}
 
-    def p_table_properties(self, p):
-        """table_properties : id id id"""
-        p_list = list(p)
-        print(p_list, "table_properties")
-        p[0] = {p_list[-3]: p_list[-1]}
-
     def p_expression_cluster_by(self, p):
         """expr : expr CLUSTER BY LP pid RP
         | expr CLUSTER BY pid
